@@ -54,14 +54,7 @@ def multiplot(*args, **kwargs):
 
     #print(args)
     for subplot in args:
-        for k,v in subplot["attribute"].items():
-            if isinstance(v, list):
-                for i in v:
-                    #print('set %s %s' %(k, i))
-                    g.cmd('set %s %s' %(k, i))
-            else:
-                #print('set %s %s' %(k, v))
-                g.cmd('set %s %s' %(k, v))
+        g.set(**subplot["attribute"])
         cmd = subplot["cmd"]
         c = subplot["subtype"]
         for cmd in subplot["cmd"]:
@@ -69,12 +62,13 @@ def multiplot(*args, **kwargs):
         #print("log multiplot(): ", c.rstrip(','))
         g.cmd(c.rstrip(','))
         # multiplot automatically unset the following setting:
-        g.unset('for [i=1:200] label i',
-                'title',
-                'xtics', 'x2tics', 'ytics', 'y2tics', 'ztics', 'cbtics',
-                'xlabel', 'x2label', 'ylabel', 'y2label', 'zlabel', 'cblabel',
-                'xrange', 'x2range', 'yrange', 'y2range', 'zrange', 'cbrange',
-                'rrange', 'trange', 'urange', 'vrange')
+        g.unset('for [i=1:200] label i')
+        #g.unset('for [i=1:200] label i',
+        #        'title',
+        #        'xtics', 'x2tics', 'ytics', 'y2tics', 'ztics', 'cbtics',
+        #        'xlabel', 'x2label', 'ylabel', 'y2label', 'zlabel', 'cblabel',
+        #        'xrange', 'x2range', 'yrange', 'y2range', 'zrange', 'cbrange',
+        #        'rrange', 'trange', 'urange', 'vrange')
     g.reset()
 
 def plot(*args, **kwargs):
@@ -85,19 +79,7 @@ def splot(*args, **kwargs):
 
 def __gnuplot(plot_cmd, *args, **kwargs):
     g = Gnuplot()
-
-    # kwargs input:
-    for k,v in kwargs.items():
-        #print('set %s %s' %(k, v))
-        #g.set(**kwargs)
-        if isinstance(v, list):
-            for i in v:
-                #print('set %s %s' %(k, i))
-                g.cmd('set %s %s' %(k, i))
-        else:
-            #print('set %s %s' %(k, v))
-            g.cmd('set %s %s' %(k, v))
-
+    g.set(**kwargs)
     c = plot_cmd
     for cmd in args:
         c += ' %s,' %(cmd)
@@ -142,7 +124,7 @@ class Gnuplot(object):
             commands += map(lambda x: x.strip(), cmd)
 
         for c in commands:
-            #print('%s' %(c))
+            #print("\033[1;34m[py-gnuplot]\033[0m%s" %(c))
             self.__call__('%s' %(c))
 
     def close(self):
@@ -188,7 +170,10 @@ class Gnuplot(object):
                     self.cmd('set %s %s' %(k, i))
             else:
                 #print('set %s %s' %(k, v))
-                self.cmd('set %s %s' %(k, v))
+                if (v == None):
+                    self.cmd('unset %s' %(k))
+                else:
+                    self.cmd('set %s %s' %(k, v))
 
     def unset(self, *items):
         for item in items:
@@ -198,17 +183,7 @@ class Gnuplot(object):
         self.cmd('reset')
 
     def plot(self, *items, **kwargs):
-        for k,v in kwargs.items():
-            #print('set %s %s' %(k, v))
-            #self.set(**kwargs)
-            if isinstance(v, list):
-                for i in v:
-                    #print('set %s %s' %(k, i))
-                    self.cmd('set %s %s' %(k, i))
-            else:
-                #print('set %s %s' %(k, v))
-                self.cmd('set %s %s' %(k, v))
-
+        self.set(**kwargs)
         c = 'plot'
         for item in items:
             c = c + " " + item + ","
@@ -224,20 +199,8 @@ class Gnuplot(object):
     #    self.cmd(cmd + '\n')
 
     def splot(self, *items, **kwargs):
+        self.set(**kwargs)
         c = 'splot'
-
-        # kwargs input:
-        for k,v in kwargs.items():
-            #print('set %s %s' %(k, v))
-            #self.set(**kwargs)
-            if isinstance(v, list):
-                for i in v:
-                    #print('set %s %s' %(k, i))
-                    self.cmd('set %s %s' %(k, i))
-            else:
-                #print('set %s %s' %(k, v))
-                self.cmd('set %s %s' %(k, v))
-
         for item in items:
             c = c + " " + item + ","
         cmd = c.rstrip(',')
