@@ -41,41 +41,41 @@ def make_plot(data, *args, **kwargs):
 def multiplot(*args, **kwargs):
     g = gnuplot.Gnuplot()
 
-    for k,v in kwargs.items():
-        #print('set %s %s' %(k, v))
-        g.cmd('set %s %s' %(k, v))
+    g.set(**kwargs)
     if 'multiplot' not in kwargs.keys():
         g.cmd('set multiplot')
 
     for subplot in args:
-        for k,v in subplot["attribute"].items():
-            if isinstance(v, list):
-                for i in v:
-                    #print('set %s %s' %(k, i))
-                    g.cmd('set %s %s' %(k, i))
-            else:
-                #print('set %s %s' %(k, v))
-                g.cmd('set %s %s' %(k, v))
+        g.set(**subplot["attribute"])
+        #for k,v in subplot["attribute"].items():
+        #    if isinstance(v, list):
+        #        for i in v:
+        #            #print('set %s %s' %(k, i))
+        #            g.cmd('set %s %s' %(k, i))
+        #    else:
+        #        #print('set %s %s' %(k, v))
+        #        g.cmd('set %s %s' %(k, v))
         cmd = subplot["cmd"]
 
         # Conver the data to string format:
         if isinstance(subplot["data"], pd.DataFrame):
             content = subplot["data"].to_csv(sep = ' ')
         else:
-            content = str(data)
-        g.cmd('$Mydata << EOD\n%s\nEOD' %(content))
+            content = str(subplot["data"])
+        g.__call__('$Mydata << EOD\n%s\nEOD' %(content))
         c = subplot["subtype"]
         for cmd in subplot["cmd"]:
             c += ' $Mydata %s, ' %(cmd)
         #print(c)
         g.cmd(c)
         # multiplot automatically unset the following setting:
-        g.unset('for [i=1:200] label i',
-                'title',
-                'xtics', 'x2tics', 'ytics', 'y2tics', 'ztics', 'cbtics',
-                'xlabel', 'x2label', 'ylabel', 'y2label', 'zlabel', 'cblabel',
-                'xrange', 'x2range', 'yrange', 'y2range', 'zrange', 'cbrange',
-                'rrange', 'trange', 'urange', 'vrange')
+        g.unset('for [i=1:200] label i')
+        #g.unset('for [i=1:200] label i',
+        #        'title',
+        #        'xtics', 'x2tics', 'ytics', 'y2tics', 'ztics', 'cbtics',
+        #        'xlabel', 'x2label', 'ylabel', 'y2label', 'zlabel', 'cblabel',
+        #        'xrange', 'x2range', 'yrange', 'y2range', 'zrange', 'cbrange',
+        #        'rrange', 'trange', 'urange', 'vrange')
     g.reset()
 
 def plot(data, *args, **kwargs):
@@ -88,23 +88,14 @@ def __gnuplot(data, plot_cmd, *args, **kwargs):
     g = gnuplot.Gnuplot()
 
     # kwargs input:
-    for k,v in kwargs.items():
-        #print('set %s %s' %(k, v))
-        #g.set(**kwargs)
-        if isinstance(v, list):
-            for i in v:
-                #print('set %s %s' %(k, i))
-                g.cmd('set %s %s' %(k, i))
-        else:
-            #print('set %s %s' %(k, v))
-            g.cmd('set %s %s' %(k, v))
+    g.set(**kwargs)
 
     # Conver the data to string format:
     if isinstance(data, pd.DataFrame):
         content = data.to_csv(sep = ' ')
     else:
         content = str(data)
-    g.cmd('$Mydata << EOD\n%s\nEOD' %(content))
+    g.__call__('$Mydata << EOD\n%s\nEOD' %(content))
     c = plot_cmd
     for cmd in args:
         c += ' $Mydata %s,' %(cmd)
@@ -121,7 +112,6 @@ class Gnuplot(gnuplot.Gnuplot):
 
     def plot(self, data, *items, **kwargs):
         self.set(**kwargs)
-
         c = 'plot'
         for item in items:
             c = c + ' "-" ' + item + ","
@@ -138,9 +128,7 @@ class Gnuplot(gnuplot.Gnuplot):
             self.__call__('e')
 
     def splot(self, data, *items, **kwargs):
-        for k,v in kwargs.items():
-            self.set(**kwargs)
-
+        self.set(**kwargs)
         c = 'splot'
         for item in items:
             c = c + ' "-" ' + item + ","
